@@ -35,6 +35,7 @@ class Stage:
         self.sys_reply_q1 = "init sys reply"  # init
         self.sys_reply_q2 = "refuse sys reply"  # refuse
         self.sys_reply_complete = "complete sys reply"  # complete
+        self.keep_user_text = kwargs.get("__KEEP_USER_TEXT__", False)
 
     @staticmethod
     def set_sys_stage_status(data: dict, label: str) -> dict:
@@ -237,7 +238,8 @@ class Stage:
             # COMPLETE FLOW
             kwargs = kwargs if kwargs is not None else {}
             kwargs = self.save_user_text(kwargs, self.stage_id, __USER_TEXT__)
-            kwargs = self.clear_user_text(kwargs)
+            if not self.keep_user_text:
+                kwargs = self.clear_user_text(kwargs)
             kwargs = self.set_true_token_pass(kwargs, stage_id=self.stage_id)
             kwargs = self.set_sys_stage_status(kwargs, StageStatus.COMPLETE)
 
